# Security Policy

If you find a vulnerability or major problem in LibRapid, please submit an Issue on GitHub or
let us know on our [Discord server](https://discord.gg/cGxTFTgCAC). Additionally, if you know
of any vulnerabilities in the dependencies LibRapid makes use of, please feel free to let us
know, and we'll try to sort it out as quickly as possible.

Thanks!
